<?php
/**
 * Exception Klasse fr Dateisystem-Fehler
 */
class IOException extends Exception {
}

/**
 * Exception Klasse fr Fehler im CSV-Format
 */
class CSVException extends Exception {
}

/**
 * Klasse, um eine CSV Datei auszulesen.
 */
class CSVFile {
    
    /**
     * Name der Datei
     *
     * @var string
     */
    protected $filename;

    /**
     * Filepointer of die Datei
     *
     * @var resource
     */
    protected $fp;
    
    /**
     * Konstruktor der Klasse
     *
     * @param string $filename
     */
    public function __construct($filename) {
        $this->filename = $filename;
    }

    /**
     * Datei ffnen
     *
     * @param string $mode
     */
    public function open($mode = 'r') {
        $this->fp = fopen($this->filename, $mode);
        if ($this->fp === false) {
        	throw new IOException('Konnte Datei nicht ffnen.');
        }
    }

    /**
     * Datei locken
     *
     * @param integer $mode
     */
    public function lock($mode = LOCK_SH) {
        if (flock($this->fp, $mode) === false) {
            throw new IOException('Konnte File Lock nicht erhalten.');
        }
    }
    
    /**
     * berprfen, ob das Ende der Datei erreicht wurde
     *
     * @return boolean
     */
    public function endOfFile() {
        return feof($this->fp);
    }

    /**
     * Eine Zeile der CSV Datei lesen
     *
     * @return array
     */
    public function readLine() {
        $line = fgets($this->fp, 1024);
        if ($line === false) {
            throw new IOException('Konnte Zeile nicht auslesen.');
        }
        $fields = explode(',', trim($line));
        if (count($fields) !== 2) {
        	throw new CSVException('Zeile hat ein ungltiges Format.');
        }
        return $fields;
    }

    /**
     * Datei schlieen.
     */
    public function close() {
        fclose($this->fp);
    }
}

try {
    $file = new CSVFile('users.csv');
    $file->open();
    $file->lock();
    while (!$file->endOfFile()) {
        $fields = $file->readLine();
        print "{$fields[0]} <{$fields[1]}>\n";
    }
    $file->close();
} catch (IOException $e) {
    // Nur Exceptions vom Typ IOException fangen.
    die("Es liegt ein Datei-Fehler vor, bitte informieren Sie den Administrator");
} catch (CSVException $e) {
    // Nur Exceptions vom Typ CSVException fangen
    die("Das Format der Datei ist nicht korrekt, bitte korrigieren Sie dieses.");
} catch (Exception $e) {
    // Alle anderen Exceptions fangen
    print $e;
    exit();
}
?>