<?php
/**
 * Klasse, um eine CSV Datei auszulesen.
 */
class CSVFile {
    
    /**
     * Name der Datei
     *
     * @var string
     */
    protected $filename;

    /**
     * Filepointer of die Datei
     *
     * @var resource
     */
    protected $fp;
    
    /**
     * Konstruktor der Klasse
     *
     * @param string $filename
     */
    public function __construct($filename) {
        $this->filename = $filename;
    }

    /**
     * Datei ffnen
     *
     * @param string $mode
     */
    public function open($mode = 'r') {
        $this->fp = fopen($this->filename, $mode);
        if ($this->fp === false) {
        	throw new Exception('Konnte Datei nicht ffnen.');
        }
    }

    /**
     * Datei locken
     *
     * @param integer $mode
     */
    public function lock($mode = LOCK_SH) {
        if (flock($this->fp, $mode) === false) {
            throw new Exception('Konnte File Lock nicht erhalten.');
        }
    }
    
    /**
     * berprfen, ob das Ende der Datei erreicht wurde
     *
     * @return boolean
     */
    public function endOfFile() {
        return feof($this->fp);
    }

    /**
     * Eine Zeile der CSV Datei lesen
     *
     * @return array
     */
    public function readLine() {
        $line = fgets($this->fp, 1024);
        if ($line === false) {
            throw new Exception('Konnte Zeile nicht auslesen.');
        }
        $fields = explode(',', trim($line));
        if (count($fields) !== 2) {
        	throw new Exception('Zeile hat ein ungltiges Format.');
        }
        return $fields;
    }

    /**
     * Datei schlieen.
     */
    public function close() {
        fclose($this->fp);
    }
}

try {
    $file = new CSVFile('users.csv');
    $file->open();
    $file->lock();
    while (!$file->endOfFile()) {
        $fields = $file->readLine();
        print "{$fields[0]} <{$fields[1]}>\n";
    }
    $file->close();
} catch (Exception $e) {
    $line = $e->getLine();
    $file = $e->getFile();
    print "Es ist ein Fehler aufgetreten:\n";
    print $e->getMessage() . "\n";
    print "Zeile {$line} in {$file}\n";
    print $e;
}
print "Dieser Text wird immer ausgegeben.\n";
?>