<?php
/**
 * Klasse, um eine CSV Datei auszulesen.
 */
class CSVFile {
    
    /**
     * Name der Datei
     *
     * @var string
     */
    protected $filename;

    /**
     * Filepointer of die Datei
     *
     * @var resource
     */
    protected $fp;
    
    /**
     * Konstruktor der Klasse
     *
     * @param string $filename
     */
    public function __construct($filename) {
        $this->filename = $filename;
    }

    /**
     * Datei ffnen
     *
     * @param string $mode
     * @return boolean
     */
    public function open($mode = 'r') {
        $this->fp = fopen($this->filename, $mode);
        if ($this->fp) {
        	return false;
        }
        return true;
    }

    /**
     * Datei locken
     *
     * @param integer $mode
     * @return boolean
     */
    public function lock($mode = LOCK_SH) {
        return flock($this->fp, $mode);
    }
    
    /**
     * berprfen, ob das Ende der Datei erreicht wurde
     *
     * @return boolean
     */
    public function endOfFile() {
        return feof($this->fp);
    }

    /**
     * Eine Zeile der CSV Datei lesen
     *
     * @return array|boolean
     */
    public function readLine() {
        $line = fgets($this->fp, 1024);
        if ($line === false) {
            return false;
        }
        $fields = explode(',', trim($line));
        if (count($fields) !== 2) {
        	return false;
        }
        return $fields;
    }

    /**
     * Datei schlieen.
     */
    public function close() {
        fclose($this->fp);
    }
}

$file = new CSVFile('users.csv');
if ($file->open() === false) {
    exit('Datei kann nicht geffnet werden.');
}
if ($file->lock() === false) {
    exit('Datei-Locking kann nicht erstellt werden.');
}
while (!$file->endOfFile()) {
    $fields = $file->readLine();
    if ($fields === false) {
    	die('Zeile kann nicht ausgelesen werden oder hat ein ungltiges Format.');
    }
    print "{$fields[0]} <{$fields[1]}>\n";
}
$file->close();
?>