<?php
/**
 * Reprsentation eines beliebigen Autos
 */
class Car {
    /**
     * Hersteller des Autos
     *
     * @var string
     */
    protected $manufacturer;

    /**
     * Farbe des Autos
     *
     * @var string
     */
    protected $color;
    
    /**
     * Kilometerstand des Autos
     *
     * @var integer
     */
    protected $milage;

    /**
     * Gibt an, ob der Motor schon gestartet wurde
     *
     * @var boolean
     */
    protected $engineStarted = false;
    
    /**
     * Konstruktor fr ein neues Auto
     *
     * @param string $manufacturer
     * @param string $color
     * @param integer $milage
     */
    public function __construct($manufacturer, $color, $milage = 0) {
        $this->manufacturer = $manufacturer;
        $this->color = $color;
        $this->milage = $milage;
    }
    
    /**
     * Destruktor des Autos
     * Falls der Motor noch luft wird dieser ausgeschalten.
     */
    public function __destruct() {
        if ($this->engineStarted) {
        	$this->stopEngine();
        }
    }
    
    /**
     * Motor anlassen
     */
    public function startEngine() {
        $this->engineStarted = true;
    }

    /**
     * Einige Kilometer fahren
     *
     * @param integer $miles
     */
    public function driveForward($miles) {
        // Wenn der Motor nicht luft, kann nicht gefahren werden.
        if ($this->engineStarted !== true) {
        	return false;
        }
        // Kilometerstand erhhen
        $this->milage = $this->milage + $miles;
        return true;
    }

    /**
     * Motor wieder stoppen
     */
    public function stopEngine() {
        $this->engineStarted = false;
    }

    /**
     * Interzeptor der verwendet wird,
     * wenn das Objekt in einem String-Kontext
     * eingesetzt wird.
     * 
     * @return string
     */
    public function __toString() {
        $string  = "Instanz der Klasse Car\n";
        $string .= " +Hersteller: {$this->manufacturer}\n";
        $string .= " +Farbe     : {$this->color}\n";
        $string .= " +Tachostand: {$this->milage}\n";
        if ($this->engineStarted === true) {
            $string .= " +Der Motor luft.\n";
        } else {
            $string .= " +Der Motor luft nicht.\n";
        }
        $string .= "\n";
        return $string;
    }
}

$bmw = new Car('BMW', 'blau');
$bmw->startEngine();
$bmw->driveForward(500);
$bmw->stopEngine();

$vw = new Car('Volkswagen', 'rot');
$vw->startEngine();
$vw->driveForward(2493);
$vw->stopEngine();

echo $bmw;
echo $vw;
?>